==> MIDITrail-Ver.1.0.4src.zip: MIDITrail/MIDITrail/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by MIDITrail.rc
//
#define IDC_MYICON                      2
#define IDD_MENUWINDOW_DIALOG           102
#define IDS_APP_TITLE                   103
#define IDD_ABOUTBOX                    103
#define IDM_ABOUT                       104
#define IDM_EXIT                        105
#define IDI_MIDITRAIL                   107
#define IDI_SMALL                       108
#define IDC_MENUWINDOW                  109
#define IDC_MIDITRAIL                   110
#define IDR_MAINFRAME                   128
#define IDD_MIDIOUT_CFG                 129
#define IDD_WINDOWSIZE_CFG              130
#define IDD_HOWTOVIEW                   131
#define IDC_COMBO_PORT_A                1000
#define IDC_COMBO_PORT_B                1001
#define IDC_COMBO_PORT_C                1002
#define IDC_COMBO_PORT_D                1003
#define IDC_COMBO_PORT_E                1004
#define IDC_COMBO_PORT_F                1005
#define IDC_WINDOWSIZE_LIST             1006
#define IDC_HOWTO_PICTURE               1009
#define IDM_OPEN_FILE                   32771
#define IDM_PLAY                        32772
#define IDM_STOP                        32773
#define IDM_VIEW_3DPIANOROLL            32774
#define IDM_OPTION_MIDIOUT              32775
#define IDM_WINDOWSIZE                  32776
#define IDM_REPEAT                      32787
#define IDM_RESET_VIEWPOINT             32790
#define IDM_SAVE_VIEWPOINT              32791
#define IDM_HOWTOVIEW                   32792
#define IDM_MANUAL                      32794
#define IDM_VIEW_2DPIANOROLL            32796
#define IDM_ENABLE_PIANOKEYBOARD        32803
#define IDM_ENABLE_RIPPLE               32804
#define IDM_ENABLE_PITCHBEND            32805
#define IDC_STATIC                      -1

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        132
#define _APS_NEXT_COMMAND_VALUE         32806
#define _APS_NEXT_CONTROL_VALUE         1010
#define _APS_NEXT_SYMED_VALUE           110
#endif
#endif

==> MIDITrail-Ver.1.1.1src.zip: MIDITrail/MIDITrail/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by MIDITrail.rc
//
#define IDC_MYICON                      2
#define IDD_MENUWINDOW_DIALOG           102
#define IDS_APP_TITLE                   103
#define IDD_ABOUTBOX                    103
#define IDM_ABOUT                       104
#define IDM_EXIT                        105
#define IDI_MIDITRAIL                   107
#define IDI_SMALL                       108
#define IDC_MENUWINDOW                  109
#define IDC_MIDITRAIL                   110
#define IDR_MAINFRAME                   128
#define IDD_MIDIOUT_CFG                 129
#define IDD_WINDOWSIZE_CFG              130
#define IDD_HOWTOVIEW                   131
#define IDD_GRAPHIC_CFG                 132
#define IDC_COMBO_PORT_A                1000
#define IDC_COMBO_PORT_B                1001
#define IDC_COMBO_PORT_C                1002
#define IDC_COMBO_PORT_D                1003
#define IDC_COMBO_PORT_E                1004
#define IDC_COMBO_PORT_F                1005
#define IDC_WINDOWSIZE_LIST             1006
#define IDC_HOWTO_PICTURE               1009
#define IDC_COMBO_MULTISAMPLETYPE       1010
#define IDM_OPEN_FILE                   32771
#define IDM_PLAY                        32772
#define IDM_STOP                        32773
#define IDM_VIEW_3DPIANOROLL            32774
#define IDM_OPTION_MIDIOUT              32775
#define IDM_WINDOWSIZE                  32776
#define IDM_REPEAT                      32787
#define IDM_RESET_VIEWPOINT             32790
#define IDM_SAVE_VIEWPOINT              32791
#define IDM_HOWTOVIEW                   32792
#define IDM_MANUAL                      32794
#define IDM_VIEW_2DPIANOROLL            32796
#define IDM_ENABLE_PIANOKEYBOARD        32803
#define IDM_ENABLE_RIPPLE               32804
#define IDM_ENABLE_PITCHBEND            32805
#define IDM_VIEW_PIANOROLLRAIN          32807
#define IDM_OPTION_GRAPHIC              32809
#define IDC_STATIC                      -1

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        133
#define _APS_NEXT_COMMAND_VALUE         32810
#define _APS_NEXT_CONTROL_VALUE         1011
#define _APS_NEXT_SYMED_VALUE           110
#endif
#endif
